/****************************************************************************
** Meta object code from reading C++ file 'monthview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.04.3/src/views/monthview/monthview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'monthview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4KOrg9MonthViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KOrg::MonthView::qt_create_metaobjectdata<qt_meta_tag_ZN4KOrg9MonthViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KOrg::MonthView",
        "fullViewChanged",
        "",
        "enabled",
        "updateView",
        "showIncidences",
        "Akonadi::Item::List",
        "incidenceList",
        "date",
        "changeIncidenceDisplay",
        "Akonadi::Item",
        "Akonadi::IncidenceChanger::ChangeType",
        "updateConfig",
        "calendarAdded",
        "Akonadi::CollectionCalendar::Ptr",
        "calendar",
        "calendarRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fullViewChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showIncidences'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const QDate &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QDate, 8 },
        }}),
        // Slot 'changeIncidenceDisplay'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, Akonadi::IncidenceChanger::ChangeType)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 }, { 0x80000000 | 11, 2 },
        }}),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calendarAdded'
        QtMocHelpers::SlotData<void(const Akonadi::CollectionCalendar::Ptr &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'calendarRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::CollectionCalendar::Ptr &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MonthView, qt_meta_tag_ZN4KOrg9MonthViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KOrg::MonthView::staticMetaObject = { {
    QMetaObject::SuperData::link<KOEventView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KOrg9MonthViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KOrg9MonthViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KOrg9MonthViewE_t>.metaTypes,
    nullptr
} };

void KOrg::MonthView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MonthView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fullViewChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->updateView(); break;
        case 2: _t->showIncidences((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 3: _t->changeIncidenceDisplay((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger::ChangeType>>(_a[2]))); break;
        case 4: _t->updateConfig(); break;
        case 5: _t->calendarAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1]))); break;
        case 6: _t->calendarRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger::ChangeType >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MonthView::*)(bool )>(_a, &MonthView::fullViewChanged, 0))
            return;
    }
}

const QMetaObject *KOrg::MonthView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KOrg::MonthView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KOrg9MonthViewE_t>.strings))
        return static_cast<void*>(this);
    return KOEventView::qt_metacast(_clname);
}

int KOrg::MonthView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KOEventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KOrg::MonthView::fullViewChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
