// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "korganizer_activities_debug.h"


Q_LOGGING_CATEGORY(KORGANIZER_ACIVITIES_LOG, "org.kde.pim.korganizer.activities", QtInfoMsg)

